aboutsummaryrefslogtreecommitdiff
path: root/src/liblzma/api/lzma/bcj.h
diff options
context:
space:
mode:
authorLasse Collin <lasse.collin@tukaani.org>2008-12-31 16:29:39 +0200
committerLasse Collin <lasse.collin@tukaani.org>2008-12-31 16:29:39 +0200
commit322ecf93c961e45a1da8c4a794a7fdacefcd7f40 (patch)
tree3fc5fbae174d255bdebced50f0695d08db0cb927 /src/liblzma/api/lzma/bcj.h
parentFixed missing quoting in configure.ac. (diff)
downloadxz-322ecf93c961e45a1da8c4a794a7fdacefcd7f40.tar.xz
Renamed lzma_options_simple to lzma_options_bcj in the API.
The internal implementation is still using the name "simple". It may need some cleanups, so I look at it later.
Diffstat (limited to '')
-rw-r--r--src/liblzma/api/lzma/bcj.h (renamed from src/liblzma/api/lzma/simple.h)22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/liblzma/api/lzma/simple.h b/src/liblzma/api/lzma/bcj.h
index 6969ffa9..33bd7da9 100644
--- a/src/liblzma/api/lzma/simple.h
+++ b/src/liblzma/api/lzma/bcj.h
@@ -1,6 +1,6 @@
/**
- * \file lzma/simple.h
- * \brief So called "simple" filters
+ * \file lzma/bcj.h
+ * \brief Branch/Call/Jump conversion filters
*
* \author Copyright (C) 1999-2006 Igor Pavlov
* \author Copyright (C) 2007 Lasse Collin
@@ -25,7 +25,7 @@
#define LZMA_FILTER_X86 LZMA_VLI_C(0x04)
/**<
- * BCJ (Branch, Call, Jump) filter for x86 binaries
+ * Filter for x86 binaries
*/
#define LZMA_FILTER_POWERPC LZMA_VLI_C(0x05)
@@ -55,17 +55,17 @@
/**
* \brief Options for so called "simple" filters
*
* The simple filters never change the size of the data. Specifying options
* for them is optional: if pointer to options is NULL, default values are
* used. You probably never need to specify these options, so just set the
* options pointer to NULL and be happy.
*
* If options with non-default values have been specified when encoding,
* the same options must also be specified when decoding.
*
* \note At the moment, none of the simple filters support
* LZMA_SYNC_FLUSH. If LZMA_SYNC_FLUSH is specified,
* LZMA_OPTIONS_ERROR will be returned. If there is need,
* partial support for LZMA_SYNC_FLUSH can be added in future.
@@ -76,7 +76,7 @@
*/
typedef struct {
/**
- * \brief Start offset for branch conversions
+ * \brief Start offset for conversions
*
* This setting is useful only when the same filter is used
* _separately_ for multiple sections of the same executable file,
@@ -91,4 +91,4 @@ typedef struct {
*/
uint32_t start_offset;
-} lzma_options_simple;
+} lzma_options_bcj;
@@ -55,17 +55,17 @@
/**
- * \brief Options for so called "simple" filters
+ * \brief Options for BCJ filters
*
@@ -55,17 +55,17 @@
*
- * The simple filters never change the size of the data. Specifying options
- * for them is optional: if pointer to options is NULL, default values are
- * used. You probably never need to specify these options, so just set the
- * options pointer to NULL and be happy.
+ * The BCJ filters never change the size of the data. Specifying options
+ * for them is optional: if pointer to options is NULL, default value is
+ * used. You probably never need to specify options to BCJ filters, so just
+ * set the options pointer to NULL and be happy.
*
* If options with non-default values have been specified when encoding,
@@ -55,17 +55,17 @@
* the same options must also be specified when decoding.
*
- * \note At the moment, none of the simple filters support
+ * \note At the moment, none of the BCJ filters support
* LZMA_SYNC_FLUSH. If LZMA_SYNC_FLUSH is specified,
* LZMA_OPTIONS_ERROR will be returned. If there is need,